@@ -465,8 +465,8 @@ def MulityPageExportFileToExcel(data:list,FlieName="data.xlsx"):
     f = xlwt.Workbook()
     sheet1 = f.add_sheet('table1', cell_overwrite_ok=True)
     Index=0
-    for i in range(0,len(data),1):
-        for j in range(0,len(i),1):
+    for i in data:
+        for j in  i :
             sheet1.write(Index, 0, data[i][j])
             Index+=1
     f.save(FlieName)
